#[non_exhaustive]pub enum ResourceExhaustionKind {
AllocationLimit,
AllocationFailure,
}Expand description
The kind of resource exhaustion which prevented an operation from completing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AllocationLimit
An application-configured allocation limit was exceeded.
AllocationFailure
An allocation size could not be represented or memory could not be reserved.