classify

Function classify 

pub fn classify<'a>(err: &'a (dyn Error + 'static)) -> Classifications<'a> ⓘ
Lazily inspect the classifications of any borrowed error, including its native sources, I/O payloads and nested crate::Error values. Unknown errors are omitted and distinct causes may yield the same classification.

let error = std::io::Error::other(gix_error::not_found("missing object"));
assert!(gix_error::classify(&error).is_not_found());