pub fn validation(message: impl Into<Cow<'static, str>>) -> MessageExpand description
Create a diagnostic for invalid function or method input, classified as Class::Validation.
If the offending input is recorded, use the input key from the input validation schema.